@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2023 Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2011       Télécom-SudParis
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2011       Télécom Sud Paris
  * Copyright (C) 2016       Uppsala University
  *
  * StarPU is free software; you can redistribute it and/or modify
@@ -559,16 +559,21 @@ struct starpu_codelet
 	   systematically send all data to the memory node where the
 	   task will be executing, it will read the
 	   starpu_codelet::nodes or starpu_codelet::dyn_nodes array to
-	   determine, for each data, whether to send it on the memory
-	   node where the task will be executing (-1), or on a
-	   specific node (!= -1).
+	   determine, for each data, on which memory node to send it.
 	*/
 	unsigned specific_nodes;
 
 	/**
 	   Optional field. When starpu_codelet::specific_nodes is 1,
 	   this specifies the memory nodes where each data should be
-	   sent to for task execution. The number of entries in this
+	   sent to for task execution. This can be a specific memory
+	   node (>= 0), or any of ::STARPU_SPECIFIC_NODE_LOCAL,
+	   ::STARPU_SPECIFIC_NODE_CPU, ::STARPU_SPECIFIC_NODE_SLOW,
+	   :STARPU_SPECIFIC_NODE_FASTSTARPU_SPECIFIC_NODE_FAST,
+	   ::STARPU_SPECIFIC_NODE_LOCAL_OR_CPU,
+	   ::STARPU_SPECIFIC_NODE_NONE.
+
+	   The number of entries in this
 	   array is starpu_codelet::nbuffers, and should not exceed
 	   \ref STARPU_NMAXBUFS.
 	*/
@@ -830,12 +835,20 @@ struct starpu_task
 	   Optional pointer which is passed to the codelet through the
 	   second argument of the codelet implementation (e.g.
 	   starpu_codelet::cpu_func or starpu_codelet::cuda_func). The
-	   default value is <c>NULL</c>. starpu_codelet_pack_args()
-	   and starpu_codelet_unpack_args() are helpers that can can
-	   be used to respectively pack and unpack data into and from
-	   it, but the application can manage it any way, the only
-	   requirement is that the size of the data must be set in
-	   starpu_task::cl_arg_size .
+	   default value is <c>NULL</c>.
+
+	   Note that the pointer is passed unchanged to most drivers, so the
+	   application has to ensure the liveness of the pointed data, by using
+	   static memory or dynamic allocation (starpu_task::cl_arg_free can be
+	   used for convenience in that case).
+
+	   For the master/slave drivers however, the content pointed by cl_arg
+	   is copied to the slave, so the size of the data must be set in
+	   starpu_task::cl_arg_size.
+
+	   starpu_codelet_pack_args() and starpu_codelet_unpack_args() are
+	   helpers that can can be used to respectively pack and unpack data
+	   into and from it and update starpu_task::cl_arg_size accordingly.
 
 	   With starpu_task_insert() and alike this can be specified thanks to
 	   ::STARPU_CL_ARGS followed by a void* and a size_t.
