@@ -1,8 +1,8 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2024  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2017       Guillaume Beauchamp
- * Copyright (C) 2021       Federal University of Rio Grande do Sul (UFRGS)
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2017-2017  Guillaume Beauchamp
+ * Copyright (C) 2021-2021  Federal University of Rio Grande do Sul (UFRGS)
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -120,6 +120,20 @@ static int mpi_wait_for_all_running = 0;
 #pragma weak smpi_simulated_main_
 extern int smpi_simulated_main_(int argc, char *argv[]);
 
+static
+#if SIMGRID_VERSION >= 32600
+void
+#else
+int
+#endif
+_starpu_smpi_simulated_main(int argc, char *argv[])
+{
+#if SIMGRID_VERSION < 32600
+	return
+#endif
+		smpi_simulated_main_(argc, argv);
+}
+
 #pragma weak smpi_process_set_user_data
 #if !HAVE_DECL_SMPI_PROCESS_SET_USER_DATA && !defined(smpi_process_set_user_data)
 extern void smpi_process_set_user_data(void *);
@@ -295,7 +309,18 @@ void _starpu_mpi_submit_ready_request(void *arg)
 	{
 		STARPU_PTHREAD_MUTEX_LOCK(&progress_mutex);
 		if (req->request_type == SEND_REQ)
-			_starpu_mpi_req_prio_list_push_front(&ready_send_requests, req);
+		{
+			if (_starpu_mpi_thread_multiple_send && (ndetached_send_requests_max == 0 || ndetached_send_requests < ndetached_send_requests_max))
+			{
+				/* Directly send from this thread */
+				STARPU_PTHREAD_MUTEX_UNLOCK(&progress_mutex);
+				_starpu_mpi_handle_ready_request(req);
+				STARPU_PTHREAD_MUTEX_LOCK(&progress_mutex);
+			}
+			else
+				/* Defer to MPI thread */
+				_starpu_mpi_req_prio_list_push_front(&ready_send_requests, req);
+		}
 		else
 			_starpu_mpi_req_list_push_front(&ready_recv_requests, req);
 		_STARPU_MPI_DEBUG(3, "Pushing new request %p type %s tag %"PRIi64" src %d data %p ptr %p datatype '%s' count %d registered_datatype %d \n",
@@ -410,8 +435,7 @@ static void _starpu_mpi_isend_data_func(struct _starpu_mpi_req *req)
 #endif
 
 	// this trace event is the start of the communication link:
-	// the last parameter, set to 0, is for communication priority (not used in this MPI backend)
-	_STARPU_MPI_TRACE_ISEND_SUBMIT_END(_STARPU_MPI_FUT_POINT_TO_POINT_SEND, req, 0);
+	_STARPU_MPI_TRACE_ISEND_SUBMIT_END(_STARPU_MPI_FUT_POINT_TO_POINT_SEND, req, req->prio);
 
 	/* somebody is perhaps waiting for the MPI request to be posted */
 	STARPU_PTHREAD_MUTEX_LOCK(&req->backend->req_mutex);
@@ -1268,7 +1292,7 @@ static void *_starpu_mpi_progress_thread_func(void *arg)
 	void **tsd;
 	_STARPU_CALLOC(tsd, MAX_TSD + 1, sizeof(void*));
 #if defined(HAVE_SG_ACTOR_DATA) || defined(HAVE_SG_ACTOR_SET_DATA)
-	_starpu_simgrid_actor_create("main", smpi_simulated_main_, _starpu_simgrid_get_host_by_name("MAIN"), *(argc_argv->argc), argv_cpy);
+	_starpu_simgrid_actor_create("main", _starpu_smpi_simulated_main, _starpu_simgrid_get_host_by_name("MAIN"), *(argc_argv->argc), argv_cpy);
 	/* And set TSD for us */
 #ifdef HAVE_SG_ACTOR_SET_DATA
 	sg_actor_set_data(sg_actor_self(), tsd);
@@ -1276,7 +1300,7 @@ static void *_starpu_mpi_progress_thread_func(void *arg)
 	sg_actor_data_set(sg_actor_self(), tsd);
 #endif
 #else
-	MSG_process_create_with_arguments("main", smpi_simulated_main_, NULL, _starpu_simgrid_get_host_by_name("MAIN"), *(argc_argv->argc), argv_cpy);
+	MSG_process_create_with_arguments("main", _starpu_smpi_simulated_main, NULL, _starpu_simgrid_get_host_by_name("MAIN"), *(argc_argv->argc), argv_cpy);
 	/* And set TSD for us */
 	if (!smpi_process_set_user_data)
 	{
