@@ -1,7 +1,7 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2021  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2013       Thibaut Lambert
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2013-2013  Thibaut Lambert
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -38,35 +38,40 @@ void callback(void *arg)
 
 typedef void (*check_func)(starpu_data_handle_t handle, int i, int rank, int *error);
 
-int exchange(int rank, starpu_data_handle_t *handles, check_func func, int detached)
+int exchange(int rank, starpu_data_handle_t *handles, starpu_mpi_tag_t initial_tag, check_func func, int detached)
 {
 	int other_rank = rank%2 == 0 ? rank+1 : rank-1;
 	int i;
+	int ret;
 
 	if (rank%2)
 	{
-		starpu_mpi_send(handles[0], other_rank, 0, MPI_COMM_WORLD);
-		starpu_mpi_send(handles[NB-1], other_rank, NB-1, MPI_COMM_WORLD);
+		ret = starpu_mpi_send(handles[0], other_rank, initial_tag+0, MPI_COMM_WORLD);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_send");
+		ret = starpu_mpi_send(handles[NB-1], other_rank, initial_tag+NB-1, MPI_COMM_WORLD);
+		STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_send");
 		for(i=1 ; i<NB-1 ; i++)
 		{
-			starpu_mpi_send(handles[i], other_rank, i, MPI_COMM_WORLD);
+			ret = starpu_mpi_send(handles[i], other_rank, initial_tag+i, MPI_COMM_WORLD);
+			STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_send");
 		}
 		return 0;
 	}
 	else
 	{
-		int ret=0;
 		starpu_mpi_req req[NB];
 		int received = 0;
 
 		if (detached)
 		{
-			starpu_mpi_irecv_detached(handles[0], other_rank, 0, MPI_COMM_WORLD, callback, &received);
+			ret = starpu_mpi_irecv_detached(handles[0], other_rank, initial_tag+0, MPI_COMM_WORLD, callback, &received);
+			STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_irecv_detached");
 		}
 		else
 		{
 			memset(req, 0, NB*sizeof(starpu_mpi_req));
-			starpu_mpi_irecv(handles[0], &req[0], other_rank, 0, MPI_COMM_WORLD);
+			ret = starpu_mpi_irecv(handles[0], &req[0], other_rank, initial_tag+0, MPI_COMM_WORLD);
+			STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_irecv");
 			STARPU_ASSERT(req[0] != NULL);
 		}
 
@@ -76,11 +81,13 @@ int exchange(int rank, starpu_data_handle_t *handles, check_func func, int detac
 		{
 			if (detached)
 			{
-				starpu_mpi_irecv_detached(handles[i], other_rank, i, MPI_COMM_WORLD, callback, &received);
+				ret = starpu_mpi_irecv_detached(handles[i], other_rank, initial_tag+i, MPI_COMM_WORLD, callback, &received);
+				STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_irecv_detached");
 			}
 			else
 			{
-				starpu_mpi_irecv(handles[i], &req[i], other_rank, i, MPI_COMM_WORLD);
+				ret = starpu_mpi_irecv(handles[i], &req[i], other_rank, initial_tag+i, MPI_COMM_WORLD);
+				STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_irecv");
 				STARPU_ASSERT(req[i] != NULL);
 			}
 		}
@@ -99,8 +106,9 @@ int exchange(int rank, starpu_data_handle_t *handles, check_func func, int detac
 		{
 			for(i=0 ; i<NB ; i++)
 			{
-			     starpu_mpi_wait(&req[i], MPI_STATUS_IGNORE);
-			     func(handles[i], i, rank, &ret);
+				ret = starpu_mpi_wait(&req[i], MPI_STATUS_IGNORE);
+				STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_wait");
+				func(handles[i], i, rank, &ret);
 			}
 		}
 		return ret;
@@ -121,7 +129,7 @@ void check_variable(starpu_data_handle_t handle, int i, int rank, int *error)
 	starpu_data_release(handle);
 }
 
-int exchange_variable(int rank, int detached)
+int exchange_variable(int rank, starpu_mpi_tag_t initial_tag, int detached)
 {
 	int ret, i;
 	starpu_data_handle_t tab_handle[NB];
@@ -135,7 +143,7 @@ int exchange_variable(int rank, int detached)
 		starpu_variable_data_register(&tab_handle[i], STARPU_MAIN_RAM, (uintptr_t)&value[i], sizeof(int));
 		starpu_mpi_data_register(tab_handle[i], i, rank);
 	}
-	ret = exchange(rank, tab_handle, check_variable, detached);
+	ret = exchange(rank, tab_handle, initial_tag, check_variable, detached);
 	for(i=0 ; i<NB ; i++)
 		starpu_data_unregister(tab_handle[i]);
 
@@ -150,7 +158,7 @@ void check_void(starpu_data_handle_t handle, int i, int rank, int *error)
 	(void)error;
 }
 
-int exchange_void(int rank, int detached)
+int exchange_void(int rank, starpu_mpi_tag_t initial_tag, int detached)
 {
 	int ret, i;
 	starpu_data_handle_t tab_handle[NB];
@@ -165,7 +173,7 @@ int exchange_void(int rank, int detached)
 		starpu_void_data_register(&tab_handle[i]);
 		starpu_mpi_data_register(tab_handle[i], i, rank);
 	}
-	ret = exchange(rank, tab_handle, check_void, detached);
+	ret = exchange(rank, tab_handle, initial_tag, check_void, detached);
 	for(i=0 ; i<NB ; i++)
 		starpu_data_unregister(tab_handle[i]);
 
@@ -186,7 +194,7 @@ void check_complex(starpu_data_handle_t handle, int i, int rank, int *error)
 	}
 }
 
-int exchange_complex(int rank, int detached)
+int exchange_complex(int rank, starpu_mpi_tag_t initial_tag, int detached)
 {
 	int ret, i;
 	starpu_data_handle_t handle[NB];
@@ -202,7 +210,7 @@ int exchange_complex(int rank, int detached)
 		starpu_complex_data_register(&handle[i], STARPU_MAIN_RAM, &real[i], &imaginary[i], 1);
 		starpu_mpi_data_register(handle[i], i, rank);
 	}
-	ret = exchange(rank, handle, check_complex, detached);
+	ret = exchange(rank, handle, initial_tag, check_complex, detached);
 	for(i=0 ; i<NB ; i++)
 		starpu_data_unregister(handle[i]);
 
@@ -214,10 +222,18 @@ int main(int argc, char **argv)
 	int ret=0, global_ret=0;
 	int rank, size;
 	int mpi_init;
+	struct starpu_conf conf;
+	starpu_mpi_tag_t initial_tag = 0;
 
 	MPI_INIT_THREAD(&argc, &argv, MPI_THREAD_SERIALIZED, &mpi_init);
 
-	ret = starpu_mpi_init_conf(&argc, &argv, mpi_init, MPI_COMM_WORLD, NULL);
+	starpu_conf_init(&conf);
+	starpu_conf_noworker(&conf);
+	conf.ncpus = -1;
+	conf.nmpi_ms = -1;
+	conf.ntcpip_ms = -1;
+
+	ret = starpu_mpi_init_conf(&argc, &argv, mpi_init, MPI_COMM_WORLD, &conf);
 	STARPU_CHECK_RETURN_VALUE(ret, "starpu_mpi_init_conf");
 
 	starpu_mpi_comm_rank(MPI_COMM_WORLD, &rank);
@@ -232,27 +248,33 @@ int main(int argc, char **argv)
 		return rank == 0 ? STARPU_TEST_SKIPPED : 0;
 	}
 
-	ret = exchange_variable(rank, 0);
+	ret = exchange_variable(rank, initial_tag, 0);
+	initial_tag += NB;
 	if (ret != 0)
 		global_ret = ret;
 
-	ret = exchange_variable(rank, 1);
+	ret = exchange_variable(rank, initial_tag, 1);
+	initial_tag += NB;
 	if (ret != 0)
 		global_ret = ret;
 
-	ret = exchange_void(rank, 0);
+	ret = exchange_void(rank, initial_tag, 0);
+	initial_tag += NB;
 	if (ret != 0)
 		global_ret = ret;
 
-	ret = exchange_void(rank, 1);
+	ret = exchange_void(rank, initial_tag, 1);
+	initial_tag += NB;
 	if (ret != 0)
 		global_ret = ret;
 
-	ret = exchange_complex(rank, 0);
+	ret = exchange_complex(rank, initial_tag, 0);
+	initial_tag += NB;
 	if (ret != 0)
 		global_ret = ret;
 
-	ret = exchange_complex(rank, 1);
+	ret = exchange_complex(rank, initial_tag, 1);
+	initial_tag += NB;
 	if (ret != 0)
 		global_ret = ret;
 
