@@ -1,8 +1,8 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2009-2024  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
- * Copyright (C) 2013       Thibaut Lambert
- * Copyright (C) 2016       Uppsala University
+ * Copyright (C) 2009-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2016-2016  Uppsala University
+ * Copyright (C) 2013-2013  Thibaut Lambert
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -18,6 +18,7 @@
 
 #include <stdlib.h>
 #include <stdio.h>
+#include <strings.h>
 #include <common/config.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -663,7 +664,15 @@ static void _starpu_init_topology(struct _starpu_machine_config *config)
 			}
 
 			if (weight == 1 || hwloc_bitmap_weight(log_coreset) == 1)
-				_STARPU_DISP("Warning: the current CPU binding set contains only one CPU, maybe you need to tell your job scheduler to bind on all allocated cores (e.g. --exclusive --ntasks-per-node=1 or --cpus-per-task for Slurm, or --bind-to board for openmpi), or you can use STARPU_WORKERS_GETBIND=0 to bypass it, but make sure you are not oversubscribing the machine\n");
+			{
+				const char *omp_bind = starpu_getenv("OMP_PROC_BIND");
+				_STARPU_DISP("Warning: the current CPU binding set contains only one CPU.\n");
+				if (omp_bind && strcasecmp(omp_bind, "false"))
+					_STARPU_DISP("The OMP_PROC_BIND environment variable is set to %s.\n", omp_bind);
+				else
+					_STARPU_DISP("Maybe you need to tell your job scheduler to bind on all allocated cores (e.g. --exclusive --ntasks-per-node=1 or --cpus-per-task for Slurm, or --bind-to board for openmpi).\n");
+				_STARPU_DISP("You can use STARPU_WORKERS_GETBIND=0 to bypass it, but make sure you are not oversubscribing the machine.\n");
+			}
 			topology->nusedpus = weight;
 			topology->firstusedpu = first;
 		} while(0);
@@ -1553,7 +1562,7 @@ int _starpu_bind_thread_on_cpu(int cpuid STARPU_ATTRIBUTE_UNUSED, int workerid S
 
 			if (workerid >= 0)
 				/* This shouldn't happen for workers */
-				_STARPU_DISP("[%s] Maybe check starpu_machine_display's output to determine what wrong binding happened. Hwloc reported a total of %d cores and %d threads, and to use %d threads from logical %d, perhaps there is misdetection between hwloc, the kernel and the BIOS, or an administrative allocation issue from e.g. the job scheduler?\n", hostname, config->topology.nhwworker[STARPU_CPU_WORKER][0], config->topology.nhwpus, config->topology.nusedpus, config->topology.firstusedpu);
+				_STARPU_DISP("[%s] Maybe check starpu_machine_display's output to determine what wrong binding happened. Hwloc reported a total of %d cores and %d threads, and to use %d threads from logical %d, perhaps there is misdetection between hwloc, the kernel and the BIOS, or an administrative allocation issue from e.g. the job scheduler? You may want to try to use export STARPU_WORKERS_GETBIND=0 to ignore the job scheduler binding\n", hostname, config->topology.nhwworker[STARPU_CPU_WORKER][0], config->topology.nhwpus, config->topology.nusedpus, config->topology.firstusedpu);
 			ret = -1;
 		}
 		else
@@ -1767,7 +1776,7 @@ static void _starpu_init_numa_node(struct _starpu_machine_config *config)
 					int devid = numa_logical_id == STARPU_NUMA_MAIN_RAM ? 0 : numa_logical_id;
 					int memnode = _starpu_memory_node_register(STARPU_CPU_RAM, devid);
 					_starpu_memory_manager_set_global_memory_size(memnode, _starpu_cpu_get_global_mem_size(devid, config));
-					STARPU_ASSERT_MSG(memnode < STARPU_MAXNUMANODES, "Wrong Memory Node : %d (only %d available)", memnode, STARPU_MAXNUMANODES);
+					STARPU_ASSERT_MSG_ALWAYS(memnode < STARPU_MAXNUMANODES, "Wrong Memory Node : %d (only %d available)", memnode, STARPU_MAXNUMANODES);
 					_starpu_memory_node_set_mapped(memnode);
 					numa_memory_nodes_to_hwloclogid[memnode] = numa_logical_id;
 					int numa_physical_id = _starpu_get_physical_numa_node_worker(worker);
@@ -1822,7 +1831,7 @@ static void _starpu_init_numa_node(struct _starpu_machine_config *config)
 				{
 					int memnode = _starpu_memory_node_register(STARPU_CPU_RAM, obj->logical_index);
 					_starpu_memory_manager_set_global_memory_size(memnode, _starpu_cpu_get_global_mem_size(obj->logical_index, config));
-					STARPU_ASSERT_MSG(memnode < STARPU_MAXNUMANODES, "Wrong Memory Node : %d (only %d available)", memnode, STARPU_MAXNUMANODES);
+					STARPU_ASSERT_MSG_ALWAYS(memnode < STARPU_MAXNUMANODES, "Wrong Memory Node : %d (only %d available)", memnode, STARPU_MAXNUMANODES);
 					_starpu_memory_node_set_mapped(memnode);
 					numa_memory_nodes_to_hwloclogid[memnode] = obj->logical_index;
 					numa_memory_nodes_to_physicalid[memnode] = obj->os_index;
@@ -1888,7 +1897,7 @@ static void _starpu_init_numa_node(struct _starpu_machine_config *config)
 
 		if (numa == 0)
 			STARPU_ASSERT_MSG(memnode == STARPU_MAIN_RAM, "Wrong Memory Node : %d (expected %d) \n", memnode, STARPU_MAIN_RAM);
-		STARPU_ASSERT_MSG(memnode < STARPU_MAXNUMANODES, "Wrong Memory Node : %d (only %d available) \n", memnode, STARPU_MAXNUMANODES);
+		STARPU_ASSERT_MSG_ALWAYS(memnode < STARPU_MAXNUMANODES, "Wrong Memory Node : %d (only %d available) \n", memnode, STARPU_MAXNUMANODES);
 
 #ifdef STARPU_SIMGRID
 		if (nnuma > 1)
@@ -2196,8 +2205,10 @@ void starpu_topology_print(FILE *output)
 		fprintf(output, "\t");
 #endif
 		if ((pu % nthreads_per_core) == 0)
-			fprintf(output, "core %u", pu / nthreads_per_core);
-		fprintf(output, "\tPU %u\t", pu);
+			fprintf(output, "core %-5u ", pu / nthreads_per_core);
+		else
+			fprintf(output, "           ");
+		fprintf(output, "PU %-5u ", pu);
 		for (worker = 0;
 		     worker < nworkers + ncombinedworkers;
 		     worker++)
@@ -2210,7 +2221,7 @@ void starpu_topology_print(FILE *output)
 				{
 					char name[256];
 					starpu_worker_get_name(worker, name, sizeof(name));
-					fprintf(output, "%s\t", name);
+					fprintf(output, "%-10s ", name);
 				}
 			}
 			else
@@ -2221,7 +2232,7 @@ void starpu_topology_print(FILE *output)
 				for (i = 0; i < worker_size; i++)
 				{
 					if (topology->workers_bindid[combined_workerid[i]] == pu)
-						fprintf(output, "comb %u\t", worker-nworkers);
+						fprintf(output, "comb %-5u ", worker-nworkers);
 				}
 			}
 		}
