@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2008-2023  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2008-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  * Copyright (C) 2018,2021  Federal University of Rio Grande do Sul (UFRGS)
  *
  * StarPU is free software; you can redistribute it and/or modify
@@ -545,8 +545,9 @@ int starpu_data_can_evict(starpu_data_handle_t handle, unsigned node, enum starp
 			/* TODO: rather check if that can be evicted as well, and if so unmap it before evicting this */
 			return 0;
 
-	/* This data cannnot be pushed outside CPU memory */
-	if (!handle->ooc && starpu_node_get_kind(node) == STARPU_CPU_RAM
+	/* This data cannot be pushed outside CPU memory */
+	if (!handle->ooc && handle->home_node == -1
+		&& starpu_node_get_kind(node) == STARPU_CPU_RAM
 		&& starpu_memory_nodes_get_numa_count() == 1)
 		return 0;
 
@@ -585,12 +586,16 @@ static size_t try_to_throw_mem_chunk(struct _starpu_mem_chunk *mc, unsigned node
 	 * memchunk that could be used with filters. */
 	if (mc->relaxed_coherency == 1)
 	{
-		STARPU_ASSERT(mc->replicate);
-
 		if (_starpu_spin_trylock(&handle->header_lock))
 			/* Handle is busy, abort */
 			return 0;
 
+		if (!mc->replicate) {
+			/* _starpu_request_mem_chunk_removal removed it before us */
+			_starpu_spin_unlock(&handle->header_lock);
+			return 0;
+		}
+
 		if (mc->replicate->refcnt == 0)
 		{
 			/* Note that there is no need to transfer any data or
@@ -917,7 +922,7 @@ restart:
 }
 
 /*
- * Free the memory chunks that are explicitely tagged to be freed.
+ * Free the memory chunks that are explicitly tagged to be freed.
  */
 static size_t flush_memchunk_cache(unsigned node, size_t reclaim)
 {
@@ -1066,7 +1071,7 @@ size_t _starpu_memory_reclaim_generic(unsigned node, unsigned force, size_t recl
 			{
 				char name[32];
 				starpu_memory_node_get_name(node, name, sizeof(name));
-				_STARPU_DISP("Not enough memory left on node %s. Your application data set seems too huge to fit on the device, StarPU will cope by trying to purge %lu MiB out. This message will not be printed again for further purges\n", name, (unsigned long) ((reclaim+1048575) / 1048576));
+				_STARPU_DISP("Not enough memory left on node %s. Your application data set seems too huge to fit on the device, StarPU will cope by trying to purge %lu MiB out. This message will not be printed again for further purges. You may want to tune the STARPU_MINIMUM_CLEAN_BUFFERS and STARPU_TARGET_CLEAN_BUFFERS environment variables up a bit to make StarPU maintain more clean memory available, to avoid ending up in this situation.\n", name, (unsigned long) ((reclaim+1048575) / 1048576));
 			}
 		}
 	}
@@ -1083,7 +1088,7 @@ size_t _starpu_memory_reclaim_generic(unsigned node, unsigned force, size_t recl
 }
 
 /*
- * This function frees all the memory that was implicitely allocated by StarPU
+ * This function frees all the memory that was implicitly allocated by StarPU
  * (for the data replicates). This is not ensuring data coherency, and should
  * only be called while StarPU is getting shut down.
  */
@@ -1177,8 +1182,10 @@ void starpu_memchunk_tidy(unsigned node)
 			handle = mc->data;
 			STARPU_ASSERT(handle);
 
-			/* This data cannnot be pushed outside CPU memory */
-			if (!handle->ooc && starpu_node_get_kind(node) == STARPU_CPU_RAM)
+			/* This data cannot be pushed outside CPU memory */
+			if (!handle->ooc && handle->home_node == -1
+				&& starpu_node_get_kind(node) == STARPU_CPU_RAM
+				&& starpu_memory_nodes_get_numa_count() == 1)
 				continue;
 
 			if (_starpu_spin_trylock(&handle->header_lock))
@@ -1215,7 +1222,7 @@ void starpu_memchunk_tidy(unsigned node)
 				 * dropping it! */
 				(node < sizeof(handle->wt_mask) * 8 && handle->wt_mask & (1<<node))
 				/* This is partitioned, don't care about the
-				 * whole data, we'll work on the subdatas.  */
+				 * whole data, we'll work on the subdata.  */
 			     || handle->nchildren
 				/* REDUX, can't do anything with it, skip it */
 			     || mc->relaxed_coherency == 2
@@ -1470,7 +1477,7 @@ void _starpu_request_mem_chunk_removal(starpu_data_handle_t handle, struct _star
 /*
  * In order to allocate a piece of data, we try to reuse existing buffers if
  * its possible.
- *	1 - we try to reuse a memchunk that is explicitely unused.
+ *	1 - we try to reuse a memchunk that is explicitly unused.
  *	2 - we go through the list of memory chunks and find one that is not
  *	referenced and that has the same footprint to reuse it.
  *	3 - we call the usual driver's alloc method
@@ -1743,6 +1750,29 @@ void _starpu_memchunk_wont_use(struct _starpu_mem_chunk *mc, unsigned node)
 	_starpu_spin_unlock(&node_struct->mc_lock);
 }
 
+/* This memchunk content was dropped, and thus becomes clean */
+void _starpu_memchunk_clean(struct _starpu_mem_chunk *mc, unsigned node)
+{
+	if (!mc)
+		/* user-allocated memory */
+		return;
+	if (mc->home)
+		/* Home is always clean */
+		return;
+	STARPU_ASSERT(node < STARPU_MAXNODES);
+	if (!can_evict(node))
+		/* Don't bother */
+		return;
+	struct _starpu_node *node_struct = _starpu_get_node_struct(node);
+	_starpu_spin_lock(&node_struct->mc_lock);
+	if (!mc->clean)
+	{
+		node_struct->mc_clean_nb++;
+		mc->clean = 1;
+	}
+	_starpu_spin_unlock(&node_struct->mc_lock);
+}
+
 /* This memchunk is being written to, and thus becomes dirty */
 void _starpu_memchunk_dirty(struct _starpu_mem_chunk *mc, unsigned node)
 {
@@ -1877,8 +1907,10 @@ choose_target(starpu_data_handle_t handle, unsigned node)
 			unsigned nb_numa_nodes = starpu_memory_nodes_get_numa_count();
 			for (i=0; i<nb_numa_nodes; i++)
 			{
+				struct _starpu_node *node_struct = _starpu_get_node_struct(i);
 				if (handle->per_node[i].allocated ||
-				    _starpu_memory_manager_test_allocate_size(i, size_handle) == 1)
+				    (starpu_ssize_t) size_handle < node_struct->mc_cache_size ||
+				    _starpu_memory_manager_test_allocate_size(i, size_handle - node_struct->mc_cache_size) == 1)
 				{
 					target = i;
 					break;
@@ -1898,7 +1930,7 @@ choose_target(starpu_data_handle_t handle, unsigned node)
 	else
 	{
 		/* handle->home_node == -1 */
-		/* no place for datas in RAM, we push on disk */
+		/* no place for data in RAM, we push on disk */
 		if (starpu_node_get_kind(node) == STARPU_CPU_RAM)
 		{
 			target = get_better_disk_can_accept_size(handle, node);
@@ -1909,8 +1941,10 @@ choose_target(starpu_data_handle_t handle, unsigned node)
 			unsigned nb_numa_nodes = starpu_memory_nodes_get_numa_count();
 			for (i=0; i<nb_numa_nodes; i++)
 			{
+				struct _starpu_node *node_struct = _starpu_get_node_struct(i);
 				if (handle->per_node[i].allocated ||
-				    _starpu_memory_manager_test_allocate_size(i, size_handle) == 1)
+				    (starpu_ssize_t) size_handle < node_struct->mc_cache_size ||
+				    _starpu_memory_manager_test_allocate_size(i, size_handle - node_struct->mc_cache_size) == 1)
 				{
 					target = i;
 					break;
