@@ -1,6 +1,6 @@
 /* StarPU --- Runtime system for heterogeneous multicore architectures.
  *
- * Copyright (C) 2014-2020  Université de Bordeaux, CNRS (LaBRI UMR 5800), Inria
+ * Copyright (C) 2014-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
  *
  * StarPU is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -36,6 +36,8 @@
 #endif
 #include <ucontext.h>
 
+#pragma GCC visibility push(hidden)
+
 extern starpu_pthread_key_t omp_thread_key;
 extern starpu_pthread_key_t omp_task_key;
 
@@ -66,7 +68,7 @@ struct starpu_omp_numeric_place
 };
 
 /**
- * OpenMP place for thread afinity, defined by the OpenMP spec
+ * OpenMP place for thread affinity, defined by the OpenMP spec
  */
 struct starpu_omp_place
 {
@@ -239,14 +241,11 @@ LIST_TYPE(starpu_omp_task,
 	void **starpu_buffers;
 	void *starpu_cl_arg;
 
+	/* Driver porters: adding your driver here is very optional.  */
 	/** actual task function to be run */
 	void (*cpu_f)(void **starpu_buffers, void *starpu_cl_arg);
-#ifdef STARPU_USE_CUDA
 	void (*cuda_f)(void **starpu_buffers, void *starpu_cl_arg);
-#endif
-#ifdef STARPU_USE_OPENCL
 	void (*opencl_f)(void **starpu_buffers, void *starpu_cl_arg);
-#endif
 
 	enum starpu_omp_task_state state;
 	enum starpu_omp_task_flags flags;
@@ -270,15 +269,15 @@ LIST_TYPE(starpu_omp_task,
 
 	size_t stacksize;
 
-   /*
-    * taskloop attribute
-    * */
-   int is_loop;
-   unsigned long long nb_iterations;
-   unsigned long long grainsize;
-   unsigned long long chunk;
-   unsigned long long begin_i;
-   unsigned long long end_i;
+	/*
+	 * taskloop attribute
+	 * */
+	int is_loop;
+	unsigned long long nb_iterations;
+	unsigned long long grainsize;
+	unsigned long long chunk;
+	unsigned long long begin_i;
+	unsigned long long end_i;
 )
 
 LIST_TYPE(starpu_omp_thread,
@@ -401,6 +400,8 @@ struct starpu_omp_global
  */
 extern struct starpu_omp_initial_icv_values *_starpu_omp_initial_icv_values;
 extern struct starpu_omp_global *_starpu_omp_global_state;
+extern starpu_pthread_key_t _starpu_omp_thread_key;
+extern starpu_pthread_key_t _starpu_omp_task_key;
 extern double _starpu_omp_clock_ref;
 
 /*
@@ -410,11 +411,13 @@ void _starpu_omp_environment_init(void);
 void _starpu_omp_environment_exit(void);
 int _starpu_omp_environment_check(void);
 struct starpu_omp_thread *_starpu_omp_get_thread(void);
-struct starpu_omp_region *_starpu_omp_get_region_at_level(int level);
+struct starpu_omp_region *_starpu_omp_get_region_at_level(int level) STARPU_ATTRIBUTE_VISIBILITY_DEFAULT;
 struct starpu_omp_task *_starpu_omp_get_task(void);
-int _starpu_omp_get_region_thread_num(const struct starpu_omp_region *const region);
+int _starpu_omp_get_region_thread_num(const struct starpu_omp_region *const region) STARPU_ATTRIBUTE_VISIBILITY_DEFAULT;
 void _starpu_omp_dummy_init(void);
 void _starpu_omp_dummy_shutdown(void);
 #endif // STARPU_OPENMP
 
+#pragma GCC visibility pop
+
 #endif // __OPENMP_RUNTIME_SUPPORT_H__
